@@ -28,7 +28,7 @@
 #include <QScrollBar>
 
 #include <kgamewin.h>
-#include <KStandardGameAction>
+#include <KGameStandardAction>
 #include <KStandardAction>
 #include <KLocalizedString>
 #include "ksirk_debug.h"
@@ -56,14 +56,14 @@ DecoratedGameFrame::DecoratedGameFrame(QWidget* parent,
   updateGeometry(); 
   setMouseTracking(true);
 
-  QuitAction = KStandardGameAction::quit(m_automaton->game(), SLOT(close()), this);
+  QuitAction = KGameStandardAction::quit(m_automaton->game(), &KGameWindow::close, this);
   
   initMenu ();
   initAttackMenu();
   initMoveMenu();
 
   // redirect the mouse move event to the main windows
-  connect(this, SIGNAL(mouseMoveEventReceived(QMouseEvent*)), automaton->game(), SLOT(mouseMoveEvent(QMouseEvent*)));
+  connect(this, &DecoratedGameFrame::mouseMoveEventReceived, automaton->game(), &KGameWindow::mouseMoveEvent);
 }
 
 DecoratedGameFrame::~DecoratedGameFrame()
@@ -87,15 +87,15 @@ void DecoratedGameFrame::initMenu ()
 {
   menu = new QMenu(this);
     
-  QAction* newAction = KStandardGameAction::gameNew(m_automaton->game(), SLOT(slotNewGame()), this);
+  QAction* newAction = KGameStandardAction::gameNew(m_automaton->game(), &KGameWindow::slotNewGame, this);
   
-  QAction* openAction = KStandardGameAction::load(m_automaton->game(), SLOT(slotOpenGame()), this);
+  QAction* openAction = KGameStandardAction::load(m_automaton->game(), &KGameWindow::slotOpenGame, this);
   
-  QAction* saveAction = KStandardGameAction::save(m_automaton->game(), SLOT(slotSaveGame()), this);
+  QAction* saveAction = KGameStandardAction::save(m_automaton->game(), &KGameWindow::slotSaveGame, this);
   
-  QAction* zoomInAction = KStandardAction::zoomIn(m_automaton->game(), SLOT(slotZoomIn()), this);
+  QAction* zoomInAction = KStandardAction::zoomIn(m_automaton->game(), &KGameWindow::slotZoomIn, this);
   
-  QAction* zoomOutAction = KStandardAction::zoomOut(m_automaton->game(), SLOT(slotZoomOut()), this);
+  QAction* zoomOutAction = KStandardAction::zoomOut(m_automaton->game(), &KGameWindow::slotZoomOut, this);
 
   nextPlayer =   new QAction(i18n("Next Player"), this);
   connect(nextPlayer, &QAction::triggered, m_automaton->game(), &KGameWindow::slotNextPlayer);
@@ -104,7 +104,7 @@ void DecoratedGameFrame::initMenu ()
   connect(detailsAction, &QAction::triggered, this, &DecoratedGameFrame::slotDetails);
 
   goalAction = new QAction(QIcon(), i18n("Goal"), this);
-  goalAction->setShortcut(Qt::CTRL+Qt::Key_G);
+  goalAction->setShortcut(Qt::CTRL | Qt::Key_G);
   connect(goalAction,&QAction::triggered,m_automaton->game(),&KGameWindow::slotShowGoal);
  
   menu->addAction(newAction);
@@ -243,7 +243,7 @@ void DecoratedGameFrame::contextMenuEvent( QContextMenuEvent * )
 void DecoratedGameFrame::setIcon()
 {
   KConfig config(m_automaton->game()->theWorld()->getConfigFileName());
-  KConfigGroup onugroup = config.group("onu");
+  KConfigGroup onugroup = config.group(QStringLiteral("onu"));
   QString skin = onugroup.readEntry("skinpath");
   
   QString imageFileName;
